@@ -8,6 +8,8 @@ from gv_utils.enums import RequestParam, RequestPath
 from gv_utils.geometry import BaseGeometry, encode_geometry
 from gv_utils.logger import Logger
 
+SEPARATOR = RequestPath.separator
+
 
 class Requests:
 
@@ -41,13 +43,13 @@ class Requests:
             params[RequestParam.eid] = self.__encode_list_params(eids)
         if area is not None:
             params[RequestParam.within] = encode_geometry(area)
-        return await self._get('{}/{}'.format(RequestPath.location, applyto), params)
+        return await self._get(applyto, params)
 
     async def get_road_data_point(self, area: BaseGeometry = None) -> dict:
         params = {}
         if area is not None:
             params[RequestParam.within] = encode_geometry(area)
-        return await self._get('{}/{}/{}'.format(RequestPath.mapping, RequestPath.road, RequestPath.datapoint), params)
+        return await self._get(SEPARATOR.join((RequestPath.road, RequestPath.datapoint)), params)
 
     async def get_data_point_data_quality(self, period: str, fromdatetime: datetime, datapointeids: list = None,
                                           datatypeeids: list = None, todatetime: datetime = None) -> dict:
@@ -68,7 +70,7 @@ class Requests:
     async def _get_data_quality(self, period: str, fromdatetime: datetime, locationeids: list, todatetime: datetime,
                                 applyto: str, params: dict = None) -> dict:
         return await self.__get_data(period, fromdatetime, locationeids, todatetime,
-                                     '{}/{}'.format(RequestPath.dataquality, applyto), params)
+                                     SEPARATOR.join((applyto, RequestPath.dataquality)), params)
 
     async def get_data_point_indicator(self, indicator: str, period: str, fromdatetime: datetime,
                                        datapointeids: list = None, datatypeeids: list = None,
@@ -86,7 +88,7 @@ class Requests:
         if datatypeeids is not None:
             params[RequestParam.datatype] = self.__encode_list_params(datatypeeids)
         return await self._get_indicator(indicator, period, fromdatetime, datapointeids, todatetime,
-                                         '{}/{}'.format(RequestPath.imputed, RequestPath.datapoint), params)
+                                         SEPARATOR.join((RequestPath.datapoint, RequestPath.imputed)), params)
 
     async def get_road_indicator(self, indicator: str, period: str, fromdatetime: datetime, roadeids: list = None,
                                  todatetime: datetime = None) -> dict:
@@ -99,7 +101,7 @@ class Requests:
 
         params[RequestParam.indicator] = indicator
         return await self.__get_data(period, fromdatetime, locationeids, todatetime,
-                                     '{}/{}'.format(RequestPath.indicator, applyto), params)
+                                     SEPARATOR.join((applyto, RequestPath.indicator)), params)
 
     async def __get_data(self, period: str, fromdatetime: datetime, locationeids: list, todatetime: datetime,
                          applyto: str, params) -> dict:
@@ -124,12 +126,13 @@ class Requests:
         }
         if todatetime is not None:
             params[RequestParam.todatetime] = to_str(todatetime)
-        return await self._get('{}/{}'.format(RequestPath.traveltime, RequestPath.zone), params)
+        return await self._get(SEPARATOR.join((RequestPath.zonepoint, RequestPath.traveltime)), params)
 
     async def _get(self, suffix: str, params: dict = None) -> dict:
         message = {}
         async with self.session as session:
-            async with session.get('{}/{}/'.format(self.apiurl, suffix), params=params) as resp:
+            url = '{}{}'.format(SEPARATOR.join((self.apiurl, suffix)), SEPARATOR)
+            async with session.get(url, params=params) as resp:
                 if resp.status == 200:
                     message = await parser.decode_message(await resp.text())
         return message
