@@ -118,6 +118,7 @@ class RequestParam:
 
     internalflag = 'internal'
 
+    datapoint = 'datapoint'
     datatype = 'datatype'
     eid = 'eid'
     fromdatetime = 'fromdatetime'
@@ -136,10 +137,6 @@ class RequestParam:
 class RequestPath(MessageKind):
     separator = '/'
 
-    location = 'location'
-    mapping = 'mapping'
-    zone = 'zone'
-
 
 class NetworkObjId:
     datapointsroadsmap = 'datapointsroadsmap'
